# Face Hunters

Face Hunters is a software developped by 4BIM students to help generate a criminal's portrait.

## Presentation

A crime was comitted. The victim describes the criminal to the police and in order to identify the criminal, he can use this software to find an accurate representation of his agressor's face. The victim will be shown different pictures and will be asked to choose among them whichever one is closest to the real agressor's face. The program will then use the chosen picture to generate a new set of similar faces, and so on. This way, the user will get closer and closer to reveal the real criminal's portrait.

## Installation & Execution

You can download the software using the pip tool in your terminal.

First, use pip to install the package. This will install the software as well as all the dependecies requiered to its execution.
```sh
pip install face_hunters
```

To make sure that the installation was successful you can look up the pip-installed packages:
```sh
pip list
```
You can then see the location of your package using :
```sh
pip show face_hunters
```
Go into the face_hunters folder and execute the module interface.py.
```sh
cd PATH/face_hunters
python interface.py
```

## Documentation

The documentation is accessible through the face_hunters folder :
```sh
cd PATH/face_hunters
browsername Documentation.html
```

## Github

You can also find our software and interactive documentation on https://github.com/lucieschwoertzig/4BIM_Project
